@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[2]:
+# In[138]:
 
 
 try:
@@ -12,10 +12,10 @@ except:
         pass
 
 
-# In[1]:
+# In[139]:
 
 
-version = '0.81'
+version = '0.84'
 
 import re
 import tempfile
@@ -33,7 +33,7 @@ import time
 
 # # Helper Functions
 
-# In[6]:
+# In[140]:
 
 
 def is_testing():
@@ -43,7 +43,7 @@ def is_testing():
         return False
 
 
-# In[7]:
+# In[141]:
 
 
 def isnotebook():
@@ -54,7 +54,7 @@ def isnotebook():
     return False
 
 
-# In[8]:
+# In[142]:
 
 
 def testPrint(*args):
@@ -64,13 +64,13 @@ def testPrint(*args):
 
 # # Timing
 
-# In[9]:
+# In[143]:
 
 
 timeSinceLastCallDict = {}
 
 
-# In[10]:
+# In[144]:
 
 
 def timeSinceLastCall(name):
@@ -83,7 +83,7 @@ def timeSinceLastCall(name):
     return name + ": " + time_s
 
 
-# In[11]:
+# In[145]:
 
 
 if is_testing():
@@ -92,7 +92,7 @@ if is_testing():
 
 # # Requiremtns
 
-# In[12]:
+# In[146]:
 
 
 requirements = []
@@ -124,7 +124,7 @@ import yaml
 
 # # Strings
 
-# In[13]:
+# In[147]:
 
 
 def sFloat0(f): return "{:0.0f}".format(f)
@@ -154,7 +154,7 @@ if is_testing():
     print(sFloatSci5(1.234567))
 
 
-# In[14]:
+# In[148]:
 
 
 def strUuid4():
@@ -165,14 +165,14 @@ def strUuid4():
     return uuid
 
 
-# In[15]:
+# In[149]:
 
 
 if is_testing():
     print(strUuid4())
 
 
-# In[16]:
+# In[150]:
 
 
 def strRand(n, num=True, upperCase=True, lowerCase=True):
@@ -184,7 +184,7 @@ def strRand(n, num=True, upperCase=True, lowerCase=True):
     return ''.join(random.choice(pool) for _ in range(n))
 
 
-# In[17]:
+# In[151]:
 
 
 if is_testing():
@@ -193,7 +193,7 @@ if is_testing():
     print(strRand(20, upperCase=False, lowerCase=False))
 
 
-# In[18]:
+# In[152]:
 
 
 def strMd5Pickle4(obj):
@@ -203,14 +203,14 @@ def strMd5Pickle4(obj):
     return md5.hexdigest()
 
 
-# In[19]:
+# In[153]:
 
 
 if is_testing():
     print(strMd5Pickle4(['a', 'b']))
 
 
-# In[20]:
+# In[154]:
 
 
 def strMd5String(s):
@@ -219,7 +219,7 @@ def strMd5String(s):
     return md5.hexdigest()
 
 
-# In[21]:
+# In[155]:
 
 
 if is_testing():
@@ -228,7 +228,7 @@ if is_testing():
 
 # # Multiprocess / Thread
 
-# In[22]:
+# In[156]:
 
 
 def mapThread(func, args, n=8):
@@ -253,14 +253,14 @@ if is_testing():
 
 # # Lists
 
-# In[23]:
+# In[157]:
 
 
 def liChunks(l, chunk_size):
     return [l[i:i + chunk_size] for i in range(0, len(l), chunk_size)]
 
 
-# In[24]:
+# In[158]:
 
 
 if is_testing():
@@ -269,7 +269,7 @@ if is_testing():
     print(liChunks(['a', 'b', 'c', 'd', 'e', 'f'], 3))
 
 
-# In[25]:
+# In[159]:
 
 
 def liSplit(a, number_of_splits):
@@ -277,7 +277,7 @@ def liSplit(a, number_of_splits):
     return [a[start:end] for start, end in zip(idxs[:-1], idxs[1:])]
 
 
-# In[26]:
+# In[160]:
 
 
 if is_testing():
@@ -289,7 +289,7 @@ if is_testing():
     print(liSplit(['a', 'b', 'c', 'd', 'e'], 6))
 
 
-# In[27]:
+# In[161]:
 
 
 def liJoin(l):
@@ -299,14 +299,14 @@ def liJoin(l):
     return out
 
 
-# In[28]:
+# In[162]:
 
 
 if is_testing():
     print(liJoin([['a', 'b', 'c'], ['d', 'e', 'f']]))
 
 
-# In[29]:
+# In[163]:
 
 
 def liFlatten(l):
@@ -323,7 +323,7 @@ def liFlatten(l):
         return l
 
 
-# In[30]:
+# In[164]:
 
 
 if is_testing():
@@ -333,7 +333,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[31]:
+# In[165]:
 
 
 regex_cache = {}
@@ -343,35 +343,35 @@ def sListFilter(l, re_include=".*", re_exclude='^\b$'):
     return [e for e in l if regex_cache[re_include].search(e) and not regex_cache[re_exclude].search(e)]
 
 
-# In[32]:
+# In[166]:
 
 
 if is_testing():
     sListFilter(['good x', 'other good x', 'without the letter before y'])
 
 
-# In[33]:
+# In[167]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[34]:
+# In[168]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[35]:
+# In[169]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[36]:
+# In[170]:
 
 
 def lCsv(l, force_oneline=False):
@@ -387,21 +387,21 @@ def lCsv(l, force_oneline=False):
     return ", ".join([str(e) for e in l])
 
 
-# In[37]:
+# In[171]:
 
 
 if is_testing():
     print(lCsv(['a', 'b', 1, 3.14]))
 
 
-# In[38]:
+# In[172]:
 
 
 if is_testing():
     print(lCsv([['a', 'b'], 1, 3.14]))
 
 
-# In[39]:
+# In[173]:
 
 
 if is_testing():
@@ -410,7 +410,7 @@ if is_testing():
 
 # # Text files
 
-# In[40]:
+# In[174]:
 
 
 def txtread(path):
@@ -431,7 +431,7 @@ def txtwrite(path, txt):
             return f.write(txt)
 
 
-# In[41]:
+# In[175]:
 
 
 if is_testing():
@@ -440,21 +440,21 @@ if is_testing():
 
 # # YAML files
 
-# In[42]:
+# In[176]:
 
 
 def yamlwrite(path, obj):
     txtwrite(path, yaml.dump(obj))
 
 
-# In[43]:
+# In[177]:
 
 
 def yamlread(path):
     return yaml.safe_load(txtread(path=path))
 
 
-# In[44]:
+# In[178]:
 
 
 if is_testing():
@@ -467,7 +467,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[45]:
+# In[179]:
 
 
 regex_cache = {}
@@ -479,35 +479,35 @@ def sListFilter(listOfStrings, re_include=".*", re_exclude='^\b$'):
 
 # ### Examples
 
-# In[46]:
+# In[180]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y']))
 
 
-# In[47]:
+# In[181]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[48]:
+# In[182]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[49]:
+# In[183]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[50]:
+# In[184]:
 
 
 if is_testing():
@@ -516,7 +516,7 @@ if is_testing():
 
 # # GCP Google Cloud Platform
 
-# In[51]:
+# In[185]:
 
 
 import warnings
@@ -540,7 +540,7 @@ def _gsBlob(path):
     return blob
 
 
-# In[52]:
+# In[186]:
 
 
 def gsGsToHttp(path):
@@ -550,7 +550,7 @@ def gsHttpToGs(path):
     return path.replace("https://storage.cloud.google.com/", "gs://").split("?")[0] # "?" is for possible "?authuser=0"
 
 
-# In[53]:
+# In[187]:
 
 
 def gsLs(path):
@@ -560,7 +560,7 @@ def gsLs(path):
     return ['gs://' + bucket + '/' + blob.name for blob in client.list_blobs(prefix=prefix)]
 
 
-# In[54]:
+# In[188]:
 
 
 def gsExists(path):
@@ -570,7 +570,7 @@ def gsExists(path):
     return client.blob(prefix).exists()
 
 
-# In[55]:
+# In[189]:
 
 
 def gsUploadFile(gsPath, path):
@@ -578,7 +578,7 @@ def gsUploadFile(gsPath, path):
     blob.upload_from_filename(path)
 
 
-# In[56]:
+# In[190]:
 
 
 def gsTxtread(path):
@@ -590,7 +590,7 @@ def gsTxtread(path):
     return blob.download_as_string().decode()
 
 
-# In[57]:
+# In[191]:
 
 
 def gsTxtwrite(path, s):
@@ -598,7 +598,7 @@ def gsTxtwrite(path, s):
     return blob.upload_from_string(s)
 
 
-# In[58]:
+# In[192]:
 
 
 def gsImwrite(path, img):
@@ -607,7 +607,7 @@ def gsImwrite(path, img):
     blob.upload_from_string(encimg.tobytes())
 
 
-# In[59]:
+# In[193]:
 
 
 def gsImread(path):
@@ -616,7 +616,7 @@ def gsImread(path):
     return cv2.imdecode(raw, 1)[:, :, [2, 1, 0]]
 
 
-# In[60]:
+# In[194]:
 
 
 def gsPklWrite(path, obj):
@@ -624,7 +624,7 @@ def gsPklWrite(path, obj):
     return blob.upload_from_string(pickle.dumps(obj, protocol=4))
 
 
-# In[61]:
+# In[195]:
 
 
 def gsPklRead(path):
@@ -634,7 +634,7 @@ def gsPklRead(path):
 
 # # Pickle
 
-# In[62]:
+# In[196]:
 
 
 def pklwrite(path, obj):
@@ -647,7 +647,7 @@ def pklwrite(path, obj):
             return pickle.dump(obj, f, protocol=4)
 
 
-# In[63]:
+# In[197]:
 
 
 def pklread(path):
@@ -658,7 +658,7 @@ def pklread(path):
             return pickle.load(f)
 
 
-# In[64]:
+# In[198]:
 
 
 if is_testing():
@@ -671,7 +671,7 @@ if is_testing():
 
 # # Images
 
-# In[65]:
+# In[199]:
 
 
 def imread(path):
@@ -703,41 +703,16 @@ def imjoin(imgs, axis=1, pad=0):
         imgs = [impad(img, right=pad) for img in imgs]
     return np.concatenate(imgs, axis=axis)
 
-def impad(img, top=0, bottom=0, left=0, right=0, color=255):
-    return np.pad(img, [(top, bottom), (left, right), (0, 0)], 'constant', constant_values=color)
-
-
-# In[66]:
-
-
-def imshow(array, scale=1):
-    array = imread(array)
-    if scale > 1:
-        array = imscaleNN(array, scale)
-        
-    if isnotebook():
-        display(Image.fromarray(array))
+def impad(img, top=0, bottom=0, left=0, right=0, color=255, mode='constant'):
+    if mode =='constant':
+        return np.pad(img, [(top, bottom), (left, right), (0, 0)], 'constant', constant_values=color)
+    elif mode == 'reflect':
+        return np.pad(img, [(top, bottom), (left, right), (0, 0)], 'reflect')
     else:
-        cv2.imshow('img', array[:, :, [2, 1, 0]])
-        cv2.waitKey()
+        raise RuntimeError(f"Mode '{mode}' not found")
 
 
-# In[67]:
-
-
-#if is_testing():
-#    img = imread('http://via.placeholder.com/70.png')
-#    imshow(img)
-
-
-# In[68]:
-
-
-#if is_testing():
-#    imshow('http://via.placeholder.com/70.png')
-
-
-# In[69]:
+# In[200]:
 
 
 def imscaleNN(img, s):
@@ -747,7 +722,56 @@ def imscaleBic(img, s):
     return cv2.resize(img, None, fx=s, fy=s, interpolation=cv2.INTER_CUBIC)
 
 
-# In[70]:
+# In[201]:
+
+
+def imshow(array, scale=1, force_nb=False):
+    array = imread(array)
+    if scale > 1:
+        array = imscaleNN(array, scale)
+        
+    if force_nb or isnotebook():
+        display(Image.fromarray(array))
+    else:
+        cv2.imshow('img', array[:, :, [2, 1, 0]])
+        cv2.waitKey()
+
+
+# In[202]:
+
+
+if is_testing():
+    img = imscaleNN((255 * np.random.rand(20, 20, 3)).astype(np.uint8), 10)
+    imshow(impad(img, bottom=10, right=10, mode='reflect'))
+
+
+# In[203]:
+
+
+def imDecodeBytes(imBytes):
+    import cv2
+    import numpy as np
+    x = np.fromstring(imBytes, dtype='uint8') # to 1D uint8 numpy array
+    img = cv2.imdecode(x, cv2.IMREAD_UNCHANGED)[:, :, [2, 1, 0]] # cv2 uses bgr
+    return img
+
+
+# In[204]:
+
+
+#if is_testing():
+#    img = imread('http://via.placeholder.com/70.png')
+#    imshow(img)
+
+
+# In[205]:
+
+
+#if is_testing():
+#    imshow('http://via.placeholder.com/70.png')
+
+
+# In[206]:
 
 
 if is_testing():
@@ -766,7 +790,7 @@ if is_testing():
         imshow(out_large_interbic)
 
 
-# In[71]:
+# In[207]:
 
 
 def imRepeat(img, height, width):
@@ -780,7 +804,7 @@ def imRepeat(img, height, width):
     return img
 
 
-# In[72]:
+# In[208]:
 
 
 if is_testing():
@@ -788,33 +812,33 @@ if is_testing():
     imshow(imRepeat(img_random_color_3x5, 7, 11), scale=10)
 
 
-# In[73]:
+# In[209]:
 
 
 def imNewWhite(height, width):
     return np.ones((height, width, 3)).astype(np.uint8) * 255
 
 
-# In[74]:
+# In[210]:
 
 
 if is_testing(): imshow(imNewWhite(10, 500) - 30)
 
 
-# In[75]:
+# In[211]:
 
 
 def imNewBlack(height, width):
     return np.zeros((height, width, 3)).astype(np.uint8)
 
 
-# In[76]:
+# In[212]:
 
 
 if is_testing(): imshow(imNewBlack(10, 500))
 
 
-# In[77]:
+# In[213]:
 
 
 def imAddNoiseGauss(img, std):
@@ -826,7 +850,7 @@ def imAddNoiseGauss(img, std):
 if is_testing(): imshow(imAddNoiseGauss(imNewWhite(150, 150), 30))
 
 
-# In[78]:
+# In[214]:
 
 
 def imJpgDegradation(img, quality):
@@ -839,7 +863,7 @@ def imJpgDegradation(img, quality):
 #if is_testing(): imshow(imJpgDegradation(imread('http://via.placeholder.com/150.png'), 15))
 
 
-# In[79]:
+# In[215]:
 
 
 def imCropCenter(img, size):
@@ -854,35 +878,35 @@ def imCropCenter(img, size):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[80]:
+# In[216]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 10))
 
 
-# In[81]:
+# In[217]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 49))
 
 
-# In[82]:
+# In[218]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 50))
 
 
-# In[83]:
+# In[219]:
 
 
 #if is_testing(): 
 #    imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 100))
 
 
-# In[84]:
+# In[220]:
 
 
 def imCropRandom(img, size, auto_size=True):
@@ -905,7 +929,7 @@ def imCropRandom(img, size, auto_size=True):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[85]:
+# In[221]:
 
 
 #if is_testing(): 
@@ -915,7 +939,7 @@ def imCropRandom(img, size, auto_size=True):
 #    imshow(imCropRandom(imread('http://via.placeholder.com/40.png'), 41))
 
 
-# In[86]:
+# In[222]:
 
 
 def imGallery(imgs, pad=0):
@@ -946,7 +970,7 @@ def imGallery(imgs, pad=0):
     return out
 
 
-# In[87]:
+# In[223]:
 
 
 if is_testing():
@@ -954,49 +978,49 @@ if is_testing():
     listOfDummyImagesBlackToWhite = [imNewBlack(10, 10) + 25 * i for i in range(10)]
 
 
-# In[88]:
+# In[224]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:1]))
 
 
-# In[89]:
+# In[225]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:2]))
 
 
-# In[90]:
+# In[226]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:2], pad=1))
 
 
-# In[91]:
+# In[227]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:5], pad=1))
 
 
-# In[92]:
+# In[228]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:9], pad=1))
 
 
-# In[93]:
+# In[229]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:10], pad=1))
 
 
-# In[95]:
+# In[230]:
 
 
 #if is_testing():
@@ -1004,7 +1028,7 @@ if is_testing():
 #    imshow(imGallery([img40x20, img40x20, img40x20], pad=1))
 
 
-# In[96]:
+# In[231]:
 
 
 def imAddTextHeader(img, text, h=None, size=None):
@@ -1039,9 +1063,31 @@ if is_testing():
     imshow(imAddTextHeader(imNewBlack(100, 100), 'black image', h = 20))
 
 
+# # Video
+
+# In[232]:
+
+
+#def imgsToVid(imgs, file_name='out.avi'):
+#    import cv2
+#    frame = imgs[0]
+#    height, width, layers = frame.shape
+#
+#    fourcc = cv2.VideoWriter_fourcc(*'DIVX')
+#    video = cv2.VideoWriter(file_name, fourcc, 24, (width,height))
+#
+#    for image in imgs:
+#        video.write(image[:, :, [2, 1, 0]])
+#
+#    cv2.destroyAllWindows()
+#    video.release()
+#    
+#imgsToVid(frames, 'test.avi')
+
+
 # # pytorch
 
-# In[97]:
+# In[233]:
 
 
 def ptT(img_np_uint8):
@@ -1058,7 +1104,7 @@ def ptUint8(img_tensor):
     
 
 
-# In[98]:
+# In[234]:
 
 
 if is_testing():
@@ -1070,14 +1116,14 @@ if is_testing():
 
 # # Files
 
-# In[99]:
+# In[235]:
 
 
 def fiFindByWildcard(wildcard):
     return natsort.natsorted(glob.glob(wildcard, recursive=True))
 
 
-# In[100]:
+# In[236]:
 
 
 if is_testing():
@@ -1106,7 +1152,7 @@ if is_testing():
         imshow(imGallery(imgs))
 
 
-# In[101]:
+# In[237]:
 
 
 def fiRemove(path):
@@ -1134,7 +1180,7 @@ def fiAgeHours(path):
     return (time.time() - os.stat(path)[stat.ST_MTIME]) / 3600
 
 
-# In[102]:
+# In[238]:
 
 
 if is_testing():
@@ -1166,7 +1212,7 @@ if is_testing():
         print("files: " + "\n".join(fiFindByWildcard(os.path.join(d, "**", "*"))))
 
 
-# In[103]:
+# In[239]:
 
 
 def fiUnzip(zip_path, out_dir=None, remove=False):
@@ -1181,7 +1227,7 @@ def fiUnzip(zip_path, out_dir=None, remove=False):
         zip.extractall(out_dir)
 
 
-# In[104]:
+# In[240]:
 
 
 def fiJoin(*args):
@@ -1193,7 +1239,7 @@ if is_testing():
 
 # # Jupyter
 
-# In[105]:
+# In[241]:
 
 
 def jnSettings():
@@ -1204,13 +1250,13 @@ if is_testing():
     jnSettings()
 
 
-# In[106]:
+# In[242]:
 
 
 def jnNbFullWidth():
     from IPython.core.display import display, HTML
     display(HTML("<style>.container { width:100% !important; }</style>"))
-    
+
 def jnPandasSettings():
     pd.set_option('display.max_rows', 1000)
     pd.set_option('display.max_columns', 100)
@@ -1218,7 +1264,7 @@ def jnPandasSettings():
     pd.set_option('display.max_colwidth', 100000)
 
 
-# In[107]:
+# In[243]:
 
 
 def jnImageRenderingPixelated():
@@ -1230,7 +1276,7 @@ def jnImageRenderingAuto():
     display(HTML('<style type = text/css> img { image-rendering: auto; } </style>'))
 
 
-# In[108]:
+# In[244]:
 
 
 def jnDefault():
@@ -1248,7 +1294,7 @@ if is_testing():
 
 
 
-# In[109]:
+# In[245]:
 
 
 def jnHtmlRow(strList, width=100):
@@ -1261,7 +1307,7 @@ if is_testing():
     
 
 
-# In[110]:
+# In[246]:
 
 
 def jnImgToHtmlB64(img):
@@ -1296,7 +1342,7 @@ def jnImageRow(imgs, names=None, width=100, external=False, title_img=None, titl
     display(HTML(html))
 
 
-# In[111]:
+# In[247]:
 
 
 if is_testing():
@@ -1304,7 +1350,7 @@ if is_testing():
    
 
 
-# In[112]:
+# In[248]:
 
 
 if is_testing():
@@ -1314,7 +1360,7 @@ if is_testing():
     jnImageRow(imgs, external=True, title='test')
 
 
-# In[113]:
+# In[249]:
 
 
 
@@ -1324,22 +1370,42 @@ if is_testing():
 
 # # Shell
 
-# In[114]:
+# In[250]:
 
 
 def shell(cmd):
-    result = subprocess.run(cmd, shell=True, stdout=subprocess.PIPE)
+    result = subprocess.run(cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     out = result.stdout.decode()
-    
+
     if len(out) > 0 and out[-1] == "\n":
         out = out[:-1]
-        
+
     return out
 
 
+# In[251]:
+
+
+shell_template = """/bin/bash << EOF 2>&1
+{cmd}
+EOF"""
+
+def bash(cmd, lineList=True):
+    result = subprocess.run(shell_template.format(cmd=cmd), shell=True, stdout=subprocess.PIPE)
+    out = result.stdout.decode()
+
+    if len(out) > 0 and out[-1] == "\n":
+        out = out[:-1]
+
+    if lineList:
+        return out.split('\n')
+    else:
+        return out
+
+
 # # GIT
 
-# In[115]:
+# In[252]:
 
 
 def gitGetHash():
@@ -1349,7 +1415,7 @@ if is_testing():
     print(gitGetHash())
 
 
-# In[116]:
+# In[253]:
 
 
 def gitGetBranch():
@@ -1359,7 +1425,7 @@ if is_testing():
     print(gitGetBranch())
 
 
-# In[117]:
+# In[254]:
 
 
 def gitGetMessage():
@@ -1369,7 +1435,7 @@ if is_testing():
     print(gitGetMessage())
 
 
-# In[118]:
+# In[255]:
 
 
 def gitGetAllFiles():
@@ -1379,7 +1445,7 @@ if is_testing():
     print(gitGetAllFiles())
 
 
-# In[119]:
+# In[256]:
 
 
 def gitListByTime(path=None):
@@ -1395,7 +1461,7 @@ if is_testing():
     print(gitListByTime()[-3:])
 
 
-# In[120]:
+# In[257]:
 
 
 def gitTime(path):
@@ -1406,7 +1472,7 @@ if is_testing():
     print(gitTime("__init__.py"))
 
 
-# In[121]:
+# In[258]:
 
 
 def gitTimeRaw(path):
@@ -1417,7 +1483,7 @@ if is_testing():
     print(gitTimeRaw("__init__.py"))
 
 
-# In[122]:
+# In[259]:
 
 
 def shellSortDirsBySize():
@@ -1429,14 +1495,14 @@ if is_testing():
 
 # # Package Files
 
-# In[123]:
+# In[260]:
 
 
 if is_testing():
     package_files = {}
 
 
-# In[124]:
+# In[261]:
 
 
 def shell(cmd):
@@ -1444,7 +1510,7 @@ def shell(cmd):
     return result.stdout.decode()
 
 
-# In[125]:
+# In[262]:
 
 
 if is_testing():
@@ -1476,7 +1542,7 @@ setup(
 )""".format(requirements=", ".join(["'" + r + "'" for r in requirements]), version=version)
 
 
-# In[126]:
+# In[263]:
 
 
 if is_testing():
@@ -1486,7 +1552,7 @@ description-file = README.md
 """
 
 
-# In[127]:
+# In[264]:
 
 
 if is_testing():
@@ -1509,14 +1575,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 
-# In[128]:
+# In[265]:
 
 
 if is_testing():
     package_files['README.md'] = ""
 
 
-# In[129]:
+# In[266]:
 
 
 if is_testing():
@@ -1525,7 +1591,7 @@ if is_testing():
     
 
 
-# In[130]:
+# In[267]:
 
 
 if is_testing():
@@ -1536,7 +1602,7 @@ lx/__init__.py
 """
 
 
-# In[131]:
+# In[268]:
 
 
 if is_testing():
